@@ -25,7 +25,7 @@ _geomesa-arrow(){
               return 0;
               ;;
                   export)
-              COMPREPLY=( $(compgen -W "--gzip --cql --url --output-format --no-header --attributes --max-features --hints --output" -- ${cur}));
+              COMPREPLY=( $(compgen -W "--output --gzip --cql --url --no-header --attributes --max-features --hints --output-format" -- ${cur}));
               return 0;
               ;;
                   help)
@@ -33,7 +33,7 @@ _geomesa-arrow(){
               return 0;
               ;;
                   ingest)
-              COMPREPLY=( $(compgen -W "--threads --converter --split-max-size --url --src-list --run-mode --input-format --feature-name --force --spec --no-tracking" -- ${cur}));
+              COMPREPLY=( $(compgen -W "--converter-error-mode --threads --converter --split-max-size --url --src-list --run-mode --input-format --feature-name --force --spec --no-tracking" -- ${cur}));
               return 0;
               ;;
                   get-type-names)
@@ -69,7 +69,7 @@ _geomesa-arrow(){
               return 0;
               ;;
                   convert)
-              COMPREPLY=( $(compgen -W "--max-features --cql --output-format --no-header --converter --output --gzip --feature-name --spec --hints" -- ${cur}));
+              COMPREPLY=( $(compgen -W "--attributes --cql --output --spec --feature-name --hints --converter --gzip --no-header --output-format --max-features --input-format --converter-error-mode --force" -- ${cur}));
               return 0;
               ;;
                   configure)
